SplitTextBit class

Inheritance

Constructors

SplitTextBit({Key? key, required String text, Duration delay = const Duration(milliseconds: 100), Duration duration = const Duration(milliseconds: 600), Curve ease = Curves.easeOut, Map<String, double> from = const {'opacity' : 0, 'y' : 40}, Map<String, double> to = const {'opacity' : 1, 'y' : 0}, double threshold = 0.1, String rootMargin = "-100px", String splitType = "chars", TextAlign textAlign = TextAlign.center, TextStyle? textStyle, void onLetterAnimationComplete()?})
const

Properties

delay Duration
final
duration Duration
final
ease Curve
final
from Map<String, double>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onLetterAnimationComplete → void Function()?
final
rootMargin String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitType String
final
text String
final
textAlign TextAlign
final
textStyle TextStyle?
final
threshold double
final
to Map<String, double>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SplitTextBit>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited