TextTypeBit class

Inheritance

Constructors

TextTypeBit({Key? key, required List<String> text, Duration typingSpeed = const Duration(milliseconds: 50), Duration deletingSpeed = const Duration(milliseconds: 30), Duration initialDelay = Duration.zero, Duration pauseDuration = const Duration(milliseconds: 2000), bool loop = true, bool showCursor = true, bool hideCursorWhileTyping = false, String cursorCharacter = '|', Duration cursorBlinkDuration = const Duration(milliseconds: 500), TextStyle? textStyle, List<Color>? textColors, bool startOnVisible = false, bool reverseMode = false, void onSentenceComplete(String sentence, int index)?, Map<String, int>? variableSpeed})
const

Properties

cursorBlinkDuration Duration
final
cursorCharacter String
final
deletingSpeed Duration
final
hashCode int
The hash code for this object.
no setterinherited
hideCursorWhileTyping bool
final
initialDelay Duration
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loop bool
final
onSentenceComplete → void Function(String sentence, int index)?
final
pauseDuration Duration
final
reverseMode bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCursor bool
final
startOnVisible bool
final
text List<String>
final
textColors List<Color>?
final
textStyle TextStyle?
final
typingSpeed Duration
final
variableSpeed Map<String, int>?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TextTypeBit>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited